Module: Sinatra::Partial
- Defined in:
- lib/sinatra/partial.rb,
lib/sinatra/partial/version.rb
Defined Under Namespace
Constant Summary collapse
- VERSION =
"0.4.0"
Class Method Summary collapse
-
.registered(app) ⇒ Object
This is here to allow configuration options to be set.
Class Method Details
.registered(app) ⇒ Object
This is here to allow configuration options to be set.
85 86 87 88 89 90 91 |
# File 'lib/sinatra/partial.rb', line 85 def self.registered(app) app.helpers(Partial::Helpers) # Configuration app.set :partial_underscores, false app.set :partial_template_engine, :haml end |